"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteAmqpQueue = exports.ensureAmqpQueue = exports.checkQueueExists = void 0;
const core_1 = require("@message-queue-toolkit/core");
async function checkQueueExists(connection, locatorConfig) {
    // queue check breaks channel if not successful
    const checkChannel = await connection.createChannel();
    checkChannel.on('error', () => {
        // it's OK
    });
    try {
        await checkChannel.checkQueue(locatorConfig.queueName);
        await checkChannel.close();
    }
    catch (err) {
        throw new Error(`Queue with queueName ${locatorConfig.queueName} does not exist.`);
    }
}
exports.checkQueueExists = checkQueueExists;
async function ensureAmqpQueue(connection, channel, creationConfig, locatorConfig) {
    if (creationConfig) {
        await channel.assertQueue(creationConfig.queueName, creationConfig.queueOptions);
    }
    else {
        if (!locatorConfig) {
            throw new Error('locatorConfig is mandatory when creationConfig is not set');
        }
        await checkQueueExists(connection, locatorConfig);
    }
}
exports.ensureAmqpQueue = ensureAmqpQueue;
async function deleteAmqpQueue(channel, deletionConfig, creationConfig) {
    if (!deletionConfig.deleteIfExists) {
        return;
    }
    if ((0, core_1.isProduction)() && !deletionConfig.forceDeleteInProduction) {
        throw new Error('You are running autodeletion in production. This can and probably will cause a loss of data. If you are absolutely sure you want to do this, please set deletionConfig.forceDeleteInProduction to true');
    }
    if (!creationConfig.queueName) {
        throw new Error('QueueName must be set for automatic deletion');
    }
    await channel.deleteQueue(creationConfig.queueName);
}
exports.deleteAmqpQueue = deleteAmqpQueue;
//# sourceMappingURL=amqpQueueUtils.js.map